import { IntersectionObserver } from '@nativescript-use/nativescript-intersection-observer';
import { readonly, ref } from 'nativescript-vue';
import { unrefView } from '../unrefView';
import { useEventListener } from '../useEventListener';
/**
 * Reactive detects that a target element visibility.
 *
 * @param target
 * @param options
 */
export function useIntersectionObserver(target, parentView, options) {
    let isVisibleInternal = false;
    let isVisible = ref(isVisibleInternal);
    let intersectionObserver;
    useEventListener(parentView, {
        loaded: () => {
            setTimeout(() => {
                const view = unrefView(target);
                if (view) {
                    const parent = unrefView(parentView);
                    intersectionObserver = new IntersectionObserver();
                    isVisibleInternal = intersectionObserver.isVisible(view, parent);
                    isVisible.value = isVisibleInternal;
                    intersectionObserver.track(view, parent, (visible) => {
                        if (isVisibleInternal != visible) {
                            isVisibleInternal = visible;
                            isVisible.value = visible;
                            if (options?.onChange)
                                options.onChange(visible);
                        }
                    });
                }
            }, 10);
        },
    });
    function stopTrack() {
        intersectionObserver.stopTrack();
    }
    return {
        isVisible: readonly(isVisible),
        stopTrack,
    };
}
//# sourceMappingURL=index.js.map