import { Task } from '@nativescript-use/nativescript-task';
import { isReactive, isRef, readonly, ref, shallowRef, unref, watch } from 'nativescript-vue';
export * from '@nativescript-use/nativescript-task';
/**
 * Reactive worker for multiprocessing.
 */
export function useWorker(vueFunction, options) {
    const { initialResult = null, runOnChangeState = false, inmediate = false, performance = false } = options ?? {};
    let runningCount = 0;
    const result = ref(initialResult);
    const update = ref();
    const isRunning = shallowRef(false);
    const isFinish = shallowRef(false);
    const error = shallowRef(null);
    if (runOnChangeState === true && options?.state && (isRef(options.state) || isReactive(options.state))) {
        watch(options.state, runTask, { deep: true });
    }
    function runTask(newData) {
        isRunning.value = true;
        isFinish.value = false;
        error.value = null;
        runningCount++;
        Task.start((ctx) => {
            return vueFunction(ctx);
        }, {
            state: (unref(newData) ?? unref(options?.state)),
            onProgressUpdate(updateData) {
                update.value = updateData;
                if (options?.on?.progressUpdate) {
                    options.on.progressUpdate(updateData);
                }
            },
            attachToContextFunctions: { ...(options?.attachToContextFunctions ?? {}), ...{ vueFunction } },
            performance,
        })
            .then((completed) => {
            result.value = completed.data;
            if (options?.on?.completed) {
                options.on.completed(completed.data);
            }
        })
            .catch((result) => {
            error.value = JSON.stringify(result.error);
            if (options?.on?.error) {
                options.on.error(result.error);
            }
        })
            .finally(() => {
            runningCount--;
            if (runningCount == 0) {
                isRunning.value = false;
                isFinish.value = true;
            }
        });
    }
    if (inmediate === true) {
        runTask();
    }
    return {
        result: readonly(result),
        update: readonly(update),
        isRunning: readonly(isRunning),
        isFinish: readonly(isFinish),
        error: readonly(error),
        runTask,
    };
}
//# sourceMappingURL=index.js.map